# Miko-Analyzer

[![Python package](https://github.com/Cloudac7/miko-analyzer/actions/workflows/ci.yml/badge.svg)](https://github.com/Cloudac7/miko-analyzer/actions/workflows/ci.yml)
[![Coverage Status](https://coveralls.io/repos/github/Cloudac7/miko-analyzer/badge.svg?branch=master)](https://coveralls.io/github/Cloudac7/miko-analyzer?branch=master)

> コードで占う巫女。
> Miko using code to perform divinition.

An analysis plugin for [Deep Potential](https://github.com/deepmodeling/deepmd-kit) based chemical research.

Supporting simple calculation workflow with the help of [DPDispatcher](https://github.com/deepmodeling/dpdispatcher).

## Installation

To install, clone the repository:

```
git clone https://github.com/cloudac7/miko-analyzer.git
```

and then install with `pip`:

```
cd miko-analyzer
pip install .
```

